
# Slot: caused by


holds between two entities where the occurrence, existence, or activity of one is caused by the occurrence or generation of the other

URI: [biolink:caused_by](https://w3id.org/biolink/vocab/caused_by)


## Domain and Range

[NamedThing](NamedThing.md) &#8594;  <sub>0..\*</sub> [NamedThing](NamedThing.md)

## Parents

 *  is_a: [related to](related_to.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | WIKIDATA_PROPERTY:P828 |
| **Narrow Mappings:** | | RO:0001022 |
|  | | RO:0002608 |
|  | | RO:0004019 |
|  | | RO:0004020 |
|  | | RO:0004028 |
|  | | RO:0009501 |
|  | | RTXKG1:disease_caused_by_disruption_of |
|  | | RTXKG1:disease_has_basis_in_dysfunction_of |
|  | | RTXKG1:realized_in_response_to |
|  | | RTXKG1:realized_in_response_to_stimulus |

